@@ -210,6 +210,8 @@ pub struct WebviewAttributes {
   pub proxy_url: Option<Url>,
   pub zoom_hotkeys_enabled: bool,
   pub browser_extensions_enabled: bool,
+  pub extensions_path: Option<PathBuf>,
+  pub data_store_identifier: Option<[u8; 16]>,
   pub use_https_scheme: bool,
   pub devtools: Option<bool>,
   pub background_color: Option<Color>,
@@ -272,6 +274,8 @@ impl WebviewAttributes {
       proxy_url: None,
       zoom_hotkeys_enabled: false,
       browser_extensions_enabled: false,
+      data_store_identifier: None,
+      extensions_path: None,
       use_https_scheme: false,
       devtools: None,
       background_color: None,
